@@ -1,7 +1,7 @@
-from typedpy import Structure
-from typedpy.fields import StructureClass, Map, String, OneOf, Boolean
-from typedpy.serialization import FunctionCall, deserialize_structure, serialize
-from typedpy.structures import _get_all_fields_by_name
+from .commons import wrap_val
+from .structures import Structure, _get_all_fields_by_name
+from .fields import StructureClass, Map, String, OneOf, Boolean
+from .serialization import FunctionCall, deserialize_structure, serialize
 
 
 class Deserializer(Structure):
@@ -185,3 +185,26 @@ class Serializer(Structure):
             compact=compact,
             camel_case_convert=camel_case_convert,
         )
+
+
+def deserializer_by_discriminator(class_by_discriminator_value):
+    """
+    create deserialized based on discriminator value in the input.
+
+    :param class_by_discriminator_value: a dictionary of the Structure class by the discriminator value
+    :return: A function that should be used in a mapper, for which the first argument is the key for
+             The discriminator field, and the second is the key for the data field that is deserialized based
+             on the provided class_by_discriminator_value.
+    """
+    _desererializer_by_type = {
+        k: Deserializer(t) for (k, t) in class_by_discriminator_value.items()
+    }
+
+    def _get_content(discriminator, data):
+        try:
+            return _desererializer_by_type[discriminator].deserialize(data)
+        except KeyError as e:
+            raise ValueError("discriminator: got {}; Expected one of {}".format(
+                wrap_val(discriminator), list(_desererializer_by_type.keys()))) from e
+
+    return _get_content
